@@ -1,5 +1,5 @@
 package Text::Xslate::Syntax::Metakolon;
-use Any::Moose;
+use Mouse;
 
 extends qw(Text::Xslate::Parser);
 
@@ -8,7 +8,7 @@ sub _build_line_start { '%%' }
 sub _build_tag_start  { '[%' }
 sub _build_tag_end    { '%]' }
 
-no Any::Moose;
+no Mouse;
 __PACKAGE__->meta->make_immutable();
 
 __END__
